;==============================================================
; CASEVAC - memory map include file
;
; * This file is contains the directives required to tell the
;   assembler how to map the program into an executable ROM.
; * This file also contains variable definitions for the
;   program
;
; Concept, art and programming by Patrick Beeson
;==============================================================

; WLA-DX banking setup
; --------------------
.memorymap
defaultslot 0
slotsize $4000
slot 0 $0000   ; SMS ROM start address
slot 1 $4000
slot 2 $8000
slotsize $2000
slot 3 $c000   ; SMS RAM start address
.endme

.rombankmap
bankstotal 3
banksize $4000
banks 3
.endro

; Structures
; ----------

; A structure to contain the data required to control sprite rendering
.struct Sprite
map_x       db ; x map index of the sprite
map_y       db ; y map index of the sprite
y           db ; y coordinate of the sprite on the screen
x           db ; x coordinate of the sprite on the screen
tile        db ; primary tile to draw for sprite
tile2       db ; secondary tile to draw for sprite if applicable
.endst

; Sprite coordinates consist of two components:
; 1) sprites' x & y with regards to the current map
;    (N.B. this also happens to be the sprites' coordinates on the screen); and
; 2) The indexes of which map the sprite is on (see design docs in main code)

; Also, you will notice that the y coord is placed before x in the structure.
; This may seem counter intuitive but it greatly simplifies sprite handling given
; the nature of the SMS VDP; y coordinates are stored first in the sprite table
; in VRAM.

; Variables
; ---------
.enum $c000

; Input control variables
CurrentlyPressedButtons db        ; buttons which are currently being pressed
JustPressedButtons      db        ; buttons which have just been pressed

; Gameplay control variables
DirectionOfTravel       db        ; a variable to record which direction the player is facing
                                  ; 1 = up, 2 = left, 3 = down, 4 = right
Lives                   dw        ; number of lives the player currently has
CasualtiesSaved         dw        ; number of casualties the player has picked up (this is their score)
BackgroundMatrix        dsb 1536  ; a matrix to contain the background tile indexes of the current map.
                                  ; This matrix is used to prevent the player from walking through impassable objects in the background.
CurrentColumn           dw        ; player's current column with regards to the BackgroundMatrix (BGM)
CurrentRow              dw        ; player's current row with regards to the BGM
CurrentBGMatrixAddress  dw        ; Current address within the BGM (i.e. this is the memory address within the BGM that the character
                                  ; sprite is currently on top of).

; General graphics control variables
SpriteTable             dsb 256   ; a table in local RAM representing the sprite table to send to VRAM.
                                  ; This is essentially a local copy of the sprite table which may be easily manipulated by the
								  ; program and then sent to VRAM; directly manipulating VRAM is more difficult.
SpriteTableYPointer     dw        ; a pointer to point to the current y coord address in the local sprite table
SpriteTableXTPointer    dw        ; a pointer to point to the current x coord and tile index addresses in the local sprite table
MapChangeFlag           db        ; a flag which tells the program if the map has changed or not 0 = no, 1 = yes.
                                  ; If the map has changed then the background tiles must be redrawn
WheelsTurningFlag       db        ; a flag which tells the program how to animate the movement of the ambulance's wheels
RPGYMoveFlag            db        ; a flag variable which controls how fast RPGs home on the player in the y axis

; Sound control variables
EngineSoundFlag         db        ; a flag while tells the program how to cut engine sound in and out

; Sprite control variables
Ambulance    instanceof Sprite    ; sprite object to define ambulence
ArtyRds      instanceof Sprite 10 ; sprite objects to define falling artillery rounds
NoOfArtyRds             db        ; the number of arty rounds in the game
RPGRds       instanceof Sprite 10 ; sprite objects to define flying RPG rounds
NoOfRPGRds              db        ; the number of RPG rounds in the game
IEDs         instanceof Sprite 10 ; sprite objects to define IEDs
NoOfIEDs                db        ; the number of IEDs in the game
Casualties   instanceof Sprite 10 ; sprite objects to define casualities
NoOfCas                 db        ; the number of casualties in the game
Explosion    instanceof Sprite    ; sprite object to define the explosion graphic
ExplosionCounter        dw        ; a variable to control the speed at which the explosion sprite is removed from the screen

.ende